==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Shape_detection/group__PkgShapeDetectionRANSAC.js <==
var group__PkgShapeDetectionRANSAC =
[
    [ "Concepts", "group__PkgShapeDetectionRANSACConcepts.html", "group__PkgShapeDetectionRANSACConcepts" ],
    [ "Shapes", "group__PkgShapeDetectionRANSACShapes.html", "group__PkgShapeDetectionRANSACShapes" ],
    [ "Property Maps", "group__PkgShapeDetectionRANSACPropertyMaps.html", "group__PkgShapeDetectionRANSACPropertyMaps" ],
    [ "Efficient_RANSAC", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html", [
      [ "Parameters", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html", [
        [ "Parameters", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#a65b4d7540e88e80a317a6bc46756f895", null ],
        [ "cluster_epsilon", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#ae073f536f9810f026bc013db80df042c", null ],
        [ "epsilon", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#a4a3044642b43a50e819e360a11165fdc", null ],
        [ "min_points", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#ae01052ac79f6fb97c4023a8b8b04967d", null ],
        [ "normal_threshold", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#a4da6cd7c6d2894e58a98a998b043784d", null ],
        [ "probability", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#a8a38fa26d501c5b2ca28cb31521361fb", null ]
      ] ],
      [ "Input_range", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a42a72197c28cc4d51f0ce8e93d718ebb", null ],
      [ "Normal_map", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a8339945bbfb68c9daa37255076b0807d", null ],
      [ "Plane_range", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a7c21f3bb8311070212cec5b24dbd7e45", null ],
      [ "Plane_shape", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#abcda3c0c363400ef454cac4b773441db", null ],
      [ "Point_index_range", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a93280cc2900e45efdcd84d08cb181066", null ],
      [ "Point_map", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#aec875d1f822bdeada94463a400170fcf", null ],
      [ "Shape", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#ae9046bb98745aea35b33815eda42f627", null ],
      [ "Shape_range", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#aa875616b2189a1f1e66f8029336607d3", null ],
      [ "Efficient_RANSAC", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a025df60cadcc14657e69a0c40d2449ff", null ],
      [ "~Efficient_RANSAC", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#abf112bdc16f5b84795a22b701a84e801", null ],
      [ "add_shape_factory", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a0206f3b841c4714b643f9b0869862e55", null ],
      [ "clear", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#ab4616fb26dc285cf76891f8c007657b7", null ],
      [ "clear_octrees", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#abcc4e80b8cb61f7a2b46b494166d1311", null ],
      [ "clear_shape_factories", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#acf23c3ac37e52798964f7fcbc32d7161", null ],
      [ "detect", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a574172b5f42b9797a36380433260fa39", null ],
      [ "indices_of_unassigned_points", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#acf9476d993384076e7d8342227ec30b9", null ],
      [ "input_iterator_beyond", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#afa4fe9bebfb92e024f85b0869573e429", null ],
      [ "input_iterator_first", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#afa57ac301b23f0a0004b4c623f4b9313", null ],
      [ "normal", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a557873d1ba3ffb302f0fd1210c5706ac", null ],
      [ "number_of_unassigned_points", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a2b6ed015ec9b0419ef4db15ebced470b", null ],
      [ "planes", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a9e93b052f5a1ec149e1688f84d49d2a0", null ],
      [ "point_map", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a53a3b1103f5fd840ef1497dec9823ca7", null ],
      [ "preprocess", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#ae810feb8f37633f5a844f8b309d2b203", null ],
      [ "set_input", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a258c90c7aa55ea723b742a5324442dce", null ],
      [ "shapes", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a725cbd87506926dcde8859c88c794bab", null ],
      [ "traits", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#ac05befbd42ade9141347001703625927", null ]
    ] ],
    [ "Efficient_RANSAC_traits", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html", [
      [ "Circle_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a0da102d5891254551da9f822b3839196", null ],
      [ "Collinear_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a0e548d8cad1de240c00081d41bc75a1e", null ],
      [ "Compute_scalar_product_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a74878d52c3fa52f03d5c3bc73c0d51dc", null ],
      [ "Compute_squared_length_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a27e491cf28e615e7fb9567c8e24f888f", null ],
      [ "Compute_squared_length_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#aab881ac00edf8dd153500e7e709e9560", null ],
      [ "Compute_squared_radius_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a7ae757a06aeb862c3c9083e3c6390e18", null ],
      [ "Compute_squared_radius_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a4c3cc453591f89cd282ff3f8ad750600", null ],
      [ "Compute_x_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ab11fad64876c0e69a1d862a331068621", null ],
      [ "Compute_x_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a0e584e4763c0655accd7326310c676b7", null ],
      [ "Compute_y_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ace46952d8dfa2ab2d5ecd18df826e981", null ],
      [ "Compute_y_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a88a1188f4daf654c04a6b4769c52b719", null ],
      [ "Compute_z_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ae0d8086018d01186687cb271ae093a8b", null ],
      [ "Construct_center_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a1aef7a11e4532f4483ca50426c77e57d", null ],
      [ "Construct_center_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a8e3c3c85fcff5f3d3b4a403a1e8e9ad1", null ],
      [ "Construct_circle_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#aba6716c060b0b5ed0f6feb5ff70d8e45", null ],
      [ "Construct_cross_product_vector_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#afdb739c1512343a6301bb145189d1b74", null ],
      [ "Construct_line_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ab7d1c9628f6e05afb7013376bb693872", null ],
      [ "Construct_point_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ab54383f3a16fbcc5a5933c06fb1ce953", null ],
      [ "Construct_point_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a0f91117ee9f5c79e164bcb9addb299df", null ],
      [ "Construct_point_on_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a76926dbc5a81fde98acfb192f97318b4", null ],
      [ "Construct_scaled_vector_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a778922196d8be002b8de71669a0b6727", null ],
      [ "Construct_sphere_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a096085235fc18a351d59e643e2f3e7de", null ],
      [ "Construct_sum_of_vectors_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a196685155f390f7ed26384f815e1daa2", null ],
      [ "Construct_translated_point_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a7257490859b6269512077f6661d44af6", null ],
      [ "Construct_vector_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#add7235ec481dd24e1defbefe42dff025", null ],
      [ "Construct_vector_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a78a4f56b837b263f879fefe7895ff134", null ],
      [ "FT", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a9471f9920f2f4ced91ce24840f685e76", null ],
      [ "Input_range", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a1a544bf76ff9ed4b604b0f35d01b7174", null ],
      [ "Intersect_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a15b4db99cc8338997f82fd85548efd92", null ],
      [ "Line_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a316eaa8c5dfabbe81d23ca6fad3254cd", null ],
      [ "Normal_map", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ac865b2b1e1690271da8d10106e938344", null ],
      [ "Plane_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ad5bfcf5e8db25c4e072fe9a104c35963", null ],
      [ "Point_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#aae8fba3db0c79f678a423b8e7d83ea86", null ],
      [ "Point_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a552c95ad850aa64cd21be8ceb1ab1412", null ],
      [ "Point_map", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#abf5bca925928d659a61363aa499aff54", null ],
      [ "Search_traits", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a2a0f15dd10e42515f6a010c7c65c6e67", null ],
      [ "Segment_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a3da6e8dad9123324adad3c8b002f78dc", null ],
      [ "Sphere_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a8f00b5dbd7d284afc23f26cc305832ce", null ],
      [ "Vector_2", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#add6780256eb55851d9ec8eb5ef7a0420", null ],
      [ "Vector_3", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a08fdb8debd311960a642bb4877946247", null ],
      [ "Efficient_RANSAC_traits", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a6ccba404f8a336590273afae567f2d8a", null ],
      [ "collinear_2_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#acdd04077ea6e1dea804e5810374fce6a", null ],
      [ "compute_scalar_product_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#aad4330fe79715d7662c37fd783c34232", null ],
      [ "compute_squared_length_2_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a4618564ab78e1f8491b6b190508a96f9", null ],
      [ "compute_squared_length_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ab96e75f9583b0857f5af4abdb7e22825", null ],
      [ "compute_squared_radius_2_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ab121c920412d010cabbfae76be534956", null ],
      [ "compute_squared_radius_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a9e06bab35a24d5618d621d1a93836299", null ],
      [ "compute_x_2_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ac0d4ee71b5e785241b0b2ebead23966b", null ],
      [ "compute_x_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ac2cea20f7b7874a53ad9df8daf866a56", null ],
      [ "compute_y_2_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a971d286bfedd03b2c9f4fe1bde749c71", null ],
      [ "compute_y_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ad7d3d387a45808efa45d3126450d080f", null ],
      [ "compute_z_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a456f20acd2520aad082b02005f891419", null ],
      [ "construct_center_2_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a3892a5a1d537af1bc83b0ae7ad32d194", null ],
      [ "construct_center_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#abd8b7fac8ceeb7aa6e93ac24d6f653b2", null ],
      [ "construct_circle_2_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a7bdce33c067082e2cd760727b226f01b", null ],
      [ "construct_cross_product_vector_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a443c897e77786805964b262db3c17009", null ],
      [ "construct_line_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a3ef85696caaae0d02640a72e711c3c20", null ],
      [ "construct_point_2_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ae34949b8142b1647e7b231d159488699", null ],
      [ "construct_point_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#aff81cab919a8bbe228ee6c9e54d25268", null ],
      [ "construct_point_on_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a4b6f03c05eb7e791b759911109c36a6c", null ],
      [ "construct_scaled_vector_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a62270edd63f137236e007afd3c976d55", null ],
      [ "construct_sphere_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a5745778bc56eeff68a8d560d44081d43", null ],
      [ "construct_sum_of_vectors_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a8cf0145b6276bb9ec4aabe8c89ddc5f6", null ],
      [ "construct_translated_point_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a86d3024ddb8f9a0ba9ac3e9f38e1bca5", null ],
      [ "construct_vector_2_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a70ff6f542d7c9e700beb5fc920323947", null ],
      [ "construct_vector_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#ab91f53cfd12c7235a18160c4b3b831f0", null ],
      [ "intersection_3_object", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html#a10c7b897e398bbb70939354f2856585a", null ]
    ] ]
];

==> CGAL-6.0.1-doc_html.tar.xz: doc_html/Shape_detection/group__PkgShapeDetectionRANSAC.js <==
var group__PkgShapeDetectionRANSAC =
[
    [ "Concepts", "group__PkgShapeDetectionRANSACConcepts.html", "group__PkgShapeDetectionRANSACConcepts" ],
    [ "Shapes", "group__PkgShapeDetectionRANSACShapes.html", "group__PkgShapeDetectionRANSACShapes" ],
    [ "Property Maps", "group__PkgShapeDetectionRANSACPropertyMaps.html", "group__PkgShapeDetectionRANSACPropertyMaps" ],
    [ "CGAL::Shape_detection::Efficient_RANSAC< Traits >", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html", [
      [ "Parameters", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html", [
        [ "cluster_epsilon", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#ae073f536f9810f026bc013db80df042c", null ],
        [ "epsilon", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#a4a3044642b43a50e819e360a11165fdc", null ],
        [ "min_points", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#ae01052ac79f6fb97c4023a8b8b04967d", null ],
        [ "normal_threshold", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#a4da6cd7c6d2894e58a98a998b043784d", null ],
        [ "probability", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#a8a38fa26d501c5b2ca28cb31521361fb", null ]
      ] ],
      [ "Input_range", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a42a72197c28cc4d51f0ce8e93d718ebb", null ],
      [ "Normal_map", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a8339945bbfb68c9daa37255076b0807d", null ],
      [ "Plane_range", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a7c21f3bb8311070212cec5b24dbd7e45", null ],
      [ "Plane_shape", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#abcda3c0c363400ef454cac4b773441db", null ],
      [ "Point_index_range", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a93280cc2900e45efdcd84d08cb181066", null ],
      [ "Point_map", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#aec875d1f822bdeada94463a400170fcf", null ],
      [ "Shape", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#ae9046bb98745aea35b33815eda42f627", null ],
      [ "Shape_range", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#aa875616b2189a1f1e66f8029336607d3", null ],
      [ "Efficient_RANSAC", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a025df60cadcc14657e69a0c40d2449ff", null ],
      [ "~Efficient_RANSAC", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#abf112bdc16f5b84795a22b701a84e801", null ],
      [ "add_shape_factory", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a0206f3b841c4714b643f9b0869862e55", null ],
      [ "clear", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#ab4616fb26dc285cf76891f8c007657b7", null ],
      [ "clear_octrees", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#abcc4e80b8cb61f7a2b46b494166d1311", null ],
      [ "clear_shape_factories", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#acf23c3ac37e52798964f7fcbc32d7161", null ],
      [ "detect", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a574172b5f42b9797a36380433260fa39", null ],
      [ "indices_of_unassigned_points", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#acf9476d993384076e7d8342227ec30b9", null ],
      [ "normal", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a326b443d57de3286c0a62b019a29d1eb", null ],
      [ "number_of_unassigned_points", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a2b6ed015ec9b0419ef4db15ebced470b", null ],
      [ "planes", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a9e93b052f5a1ec149e1688f84d49d2a0", null ],
      [ "point_map", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a48fe25b047ddeeed0c51df639243f65f", null ],
      [ "preprocess", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#ae810feb8f37633f5a844f8b309d2b203", null ],
      [ "set_input", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a258c90c7aa55ea723b742a5324442dce", null ],
      [ "shapes", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#a725cbd87506926dcde8859c88c794bab", null ],
      [ "traits", "classCGAL_1_1Shape__detection_1_1Efficient__RANSAC.html#ab09320b743e428b61b3e0bd06f3bd4c7", null ]
    ] ],
    [ "CGAL::Shape_detection::Efficient_RANSAC_traits< Gt, InputRange, InputPointMap, InputNormalMap >", "structCGAL_1_1Shape__detection_1_1Efficient__RANSAC__traits.html", null ]
];
